Skip to contents

This function adds the second, third, and fourth derivatives of the link function with respect to mu to the family object, which is used for Newton-like optimization.

Usage

# S3 method for class 'family'
fix.family.link(fam)

Arguments

fam

A family object for which to add derivatives.

Value

A modified family object with additional components for derivatives.