A dataset containing example data to be used in examples and testing of the functions in the spCorr package.
Usage
data(test_data)A dataset containing example data to be used in examples and testing of the functions in the spCorr package.
data(test_data)